/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2011  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.84                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for V850ES-JG2 V850ES-TOUCHIT startekit
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** SFRs and identifiers used for LED demo **********************/
#define	P5            (*(volatile unsigned short *)(0xfffff40A))
#define	PM5           (*(volatile unsigned short *)(0xfffff42A))
#define	PMC5          (*(volatile unsigned short *)(0xfffff44A))

/****** Target specific configuration *******************************/

#define LED0_BIT         (0)  /* LED D4 on EK board, active low */
#define LED1_BIT         (1)  /* LED D5 on EK board, active low */

#define LEDPORT          (P5)
#define LEDPORT_PORT_EN  (PMC5)
#define LEDPORT_OUT_EN   (PM5)
#define LEDPORT_STATE    (P5)

#define LEDMASK_ALL      ((1uL << LED0_BIT) | (1uL << LED1_BIT))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  LEDPORT_PORT_EN &= ~(LEDMASK_ALL);  // Enable port for all LEDs. 0 => Port function 
  LEDPORT_OUT_EN  &= ~(LEDMASK_ALL);  // Set output mode for all LEDs. 0 => output-mode
  LEDPORT         |=  (LEDMASK_ALL);  // Initially, switch LEDs off, LED is switched active low
}

/*********************************************************************
*
*       LED switching routines
*       LEDs are switched on with low level on port lines
*/
void BSP_SetLED(int Index) {
  LEDPORT &= ~((1uL << (Index + LED0_BIT)) & LEDMASK_ALL);  /* Switch on LED, active low */
}

void BSP_ClrLED(int Index) {
  LEDPORT |=  ((1uL << (Index + LED0_BIT)) & LEDMASK_ALL); /* Switch off LED, active low, => Set bit to clear LED */
}

void BSP_ToggleLED(int Index) {
  if (LEDPORT_STATE & (1 << (Index + LED0_BIT))) {        /* LED is switched off */
    BSP_SetLED(Index);
  } else {
    BSP_ClrLED(Index);
  }
}

/****** End Of File *************************************************/
